==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/TagReferencePolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TagReferencePolicyBuilder extends io.fabric8.openshift.api.model.TagReferencePolicyFluentImpl<io.fabric8.openshift.api.model.TagReferencePolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.TagReferencePolicy,io.fabric8.openshift.api.model.TagReferencePolicyBuilder>{
  public TagReferencePolicyBuilder() {
    this(false);
  }
  public TagReferencePolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new TagReferencePolicy(), validationEnabled);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TagReferencePolicy(), validationEnabled);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagReferencePolicy instance) {
    this(fluent, instance, false);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagReferencePolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicy instance) {
    this(instance,false);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.TagReferencePolicy build() {
    TagReferencePolicy buildable = new TagReferencePolicy(fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TagReferencePolicyBuilder that = (TagReferencePolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/TagReferencePolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TagReferencePolicyBuilder extends io.fabric8.openshift.api.model.TagReferencePolicyFluentImpl<io.fabric8.openshift.api.model.TagReferencePolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.TagReferencePolicy,io.fabric8.openshift.api.model.TagReferencePolicyBuilder>{
  public TagReferencePolicyBuilder() {
    this(false);
  }
  public TagReferencePolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new TagReferencePolicy(), validationEnabled);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TagReferencePolicy(), validationEnabled);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagReferencePolicy instance) {
    this(fluent, instance, false);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent,io.fabric8.openshift.api.model.TagReferencePolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicy instance) {
    this(instance,false);
  }
  public TagReferencePolicyBuilder(io.fabric8.openshift.api.model.TagReferencePolicy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.TagReferencePolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.TagReferencePolicy build() {
    TagReferencePolicy buildable = new TagReferencePolicy(fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TagReferencePolicyBuilder that = (TagReferencePolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
